package com.molin.study_class.utils.execl;

import com.alibaba.excel.write.handler.AbstractRowWriteHandler;
import com.alibaba.excel.write.metadata.holder.WriteSheetHolder;
import com.alibaba.excel.write.metadata.holder.WriteTableHolder;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.util.CellRangeAddress;

/**
 * @author David
 * @date 2025年06月12日
 * @description: 单元格合并器--固定单元格的合并（多用于表头固定字段）
 */
// 合并单元格处理器， 第一列为0，第一排为0，有5排，则endRow为4， 有5列，则endCol为4
public class MergeHeaderHandler extends AbstractRowWriteHandler {

    private final int startRow;
    private final int endRow;
    private final int startCol;
    private final int endCol;

    public MergeHeaderHandler(int startRow, int endRow, int startCol, int endCol) {
        this.startRow = startRow;
        this.endRow = endRow;
        this.startCol = startCol;
        this.endCol = endCol;
    }

    @Override
    public void afterRowDispose(WriteSheetHolder writeSheetHolder,
                                WriteTableHolder writeTableHolder,
                                Row row,
                                Integer relativeRowIndex,
                                Boolean isHead) {
        if (row.getRowNum() == startRow) { // 根据实际行号调整
            CellRangeAddress region = new CellRangeAddress(
                    startRow,
                    endRow,
                    startCol,
                    endCol
            );
            writeSheetHolder.getSheet().addMergedRegion(region);
        }
    }
}
